from distutils.core import setup
setup(
      name="xujian",
      version="1.0.0",
      py_modules = ['xujian'],
      author="xujian",
      author_email="xujian@gmail.com",
      url="http://www.xujian.com",
      description="My test module",
)
